"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useNav = void 0;
const react_1 = require("react");
const react_router_dom_1 = require("react-router-dom");
const useNavParams_1 = require("./useNavParams");
function useNav() {
    const [ctxChanged, setCtxChanged] = (0, react_1.useState)(new Date());
    const { pathname } = (0, react_router_dom_1.useLocation)();
    const navigate = (0, react_router_dom_1.useNavigate)();
    const localPathname = (0, react_1.useRef)(pathname);
    const processUrl = (0, react_1.useCallback)((rawUrl, params = {}) => {
        let url = rawUrl;
        if (url.endsWith('/*'))
            url = url.slice(0, -2);
        if (url.indexOf('*/') >= 0) {
            const separator = rawUrl.split('/')[1];
            url = url.replace('*', localPathname.current.split('/' + separator)[0]);
        }
        url = url.replace('//', '/');
        Object.keys(params).forEach(k => (url = url.replace(':' + k, params[k])));
        return url;
    }, []);
    (0, react_1.useEffect)(() => {
        localPathname.current = pathname;
        setCtxChanged(new Date());
    }, [pathname]);
    const goTo = (0, react_1.useCallback)((url, urlParams = {}, navParams = {}) => {
        useNavParams_1._navParams.current = navParams;
        navigate(processUrl(url, urlParams));
    }, [navigate, processUrl]);
    const replaceTo = (0, react_1.useCallback)((url, urlParams = {}, navParams = {}) => {
        useNavParams_1._navParams.current = navParams;
        navigate(processUrl(url, urlParams), { replace: true });
    }, [navigate, processUrl]);
    const goToOrReplace = (0, react_1.useCallback)((path, params) => {
        const fullPath = window.location.href.split('#')[1];
        const alreadyThere = !!(0, react_router_dom_1.matchPath)({ path }, fullPath);
        if (alreadyThere) {
            replaceTo(path, params);
        }
        else {
            goTo(path, params);
        }
    }, [goTo, replaceTo]);
    const goBack = (0, react_1.useCallback)(() => {
        if (window.history.length > 1)
            navigate(-1);
    }, [navigate]);
    return (0, react_1.useMemo)(() => ({
        ctxChanged,
        pathname: localPathname.current,
        goTo,
        replaceTo,
        goToOrReplace,
        goBack,
        processUrl,
    }), [ctxChanged, goBack, goTo, goToOrReplace, processUrl, replaceTo]);
}
exports.useNav = useNav;
exports.default = useNav;
//# sourceMappingURL=useNav.js.map